.. _assets:

What assets does the platform work with?
========================================

The platform supports both non-flexible assets (for monitoring and prediction) and flexible assets (for monitoring, prediction and control). The types of assets listed below are already included in the platform. Additional asset types can be set up by the Aggregator on request.

For each resource type, there exists a default mode (producer or consumer) affecting how load profiles are plotted (e.g. a consumer expects positive values to denote consumption) and whether the revenues or costs are shown.


Solar
-----

Defaults:

- Mode: producer
- Periodicity: daily, yearly


Wind
----

Defaults:

- Mode: producer
- Periodicity: daily, yearly


Battery
-------

Defaults:

- Mode: consumer
- Periodicity: none


Electric Vehicle Supply Equipment (EVSE)
--------------------------------------------------------

Defaults:

- Mode: consumer
- Periodicity: daily, weekly, yearly


Building
--------

Defaults:

- Mode: consumer
- Periodicity: daily, weekly, yearly



